@@ -5,11 +5,10 @@ from datetime import timedelta
 from bootstrap_modal_forms.generic import BSModalCreateView, BSModalUpdateView
 from django.conf import settings
 from django.contrib import messages
+from django.contrib.auth import get_user_model
 from django.contrib.auth.decorators import login_required, user_passes_test
 from django.contrib.auth.mixins import LoginRequiredMixin, \
     PermissionRequiredMixin
-from django.contrib.auth.models import User
-from django.contrib.sites.models import Site
 from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.paginator import Paginator
@@ -17,7 +16,6 @@ from django.db import OperationalError
 from django.db.models import Count, Max, Prefetch, Q
 from django.http import HttpResponse, JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
-from django.template.loader import render_to_string
 from django.urls import reverse
 from django.utils import timezone
 from django.views.decorators.http import require_POST
@@ -25,10 +23,9 @@ from django.views.decorators.http import require_POST
 from db.base.forms import SatelliteModelForm, TransmitterModelForm, \
     TransmitterUpdateForm
 from db.base.helpers import get_apikey
-from db.base.models import SERVICE_TYPE, TRANSMITTER_STATUS, \
-    TRANSMITTER_TYPE, DemodData, Mode, Satellite, Transmitter, \
+from db.base.models import DemodData, Satellite, Transmitter, \
     TransmitterEntry, TransmitterSuggestion
-from db.base.tasks import export_frames
+from db.base.tasks import export_frames, notify_transmitter_suggestion
 from db.base.utils import cache_statistics, millify, read_influx
 
 LOGGER = logging.getLogger('db')
@@ -87,19 +84,11 @@ def home(request):
                                                  ).values('station').annotate(c=Count('station')
                                                                               ).order_by('-c')
 
-    cached_stats = cache.get('stats_transmitters')
-    if not cached_stats:
-        try:
-            cache_statistics()
-            cached_stats = cache.get('stats_transmitters')
-        except OperationalError:
-            pass
     return render(
         request, 'base/home.html', {
             'newest_sats': newest_sats,
             'latest_data': latest_data,
-            'latest_submitters': latest_submitters,
-            'statistics': cached_stats
+            'latest_submitters': latest_submitters
         }
     )
 
@@ -137,23 +126,7 @@ def satellites(request):
             to_attr='approved_transmitters'
         )
     )
-    suggestion_count = TransmitterSuggestion.objects.count()
-    contributor_count = User.objects.filter(is_active=1).count()
-    cached_stats = cache.get('stats_transmitters')
-    if not cached_stats:
-        try:
-            cache_statistics()
-            cached_stats = cache.get('stats_transmitters')
-        except OperationalError:
-            pass
-    return render(
-        request, 'base/satellites.html', {
-            'satellites': satellite_objects,
-            'statistics': cached_stats,
-            'contributor_count': contributor_count,
-            'suggestion_count': suggestion_count
-        }
-    )
+    return render(request, 'base/satellites.html', {'satellites': satellite_objects})
 
 
 def satellite(request, norad):
@@ -169,19 +142,6 @@ def satellite(request, norad):
             suggestion.transmitter = original_transmitter
         except Transmitter.DoesNotExist:
             suggestion.transmitter = None
-    modes = Mode.objects.all()
-    types = TRANSMITTER_TYPE
-    services = SERVICE_TYPE
-    statuses = TRANSMITTER_STATUS
-    sat_cache = cache.get(satellite_obj.id)
-    frame_count = 0
-    if sat_cache is not None:
-        frame_count = sat_cache['count']
-
-    try:
-        latest_frame = DemodData.objects.filter(satellite=satellite_obj).order_by('-id')[0]
-    except (ObjectDoesNotExist, IndexError):
-        latest_frame = ''
 
     try:
         # pull the last 5 observers and their submission timestamps for this satellite
@@ -201,12 +161,6 @@ def satellite(request, norad):
         request, 'base/satellite.html', {
             'satellite': satellite_obj,
             'transmitter_suggestions': transmitter_suggestions,
-            'modes': modes,
-            'types': types,
-            'services': services,
-            'statuses': statuses,
-            'latest_frame': latest_frame,
-            'frame_count': frame_count,
             'mapbox_token': settings.MAPBOX_TOKEN,
             'recent_observers': recent_observers,
             'badge_telemetry_count': millify(satellite_obj.telemetry_data_count),
@@ -321,13 +275,9 @@ def stats(request):
     cached_satellites = []
     ids = cache.get('satellites_ids')
     observers = cache.get('stats_observers')
-    suggestion_count = TransmitterSuggestion.objects.count()
-    contributor_count = User.objects.filter(is_active=1).count()
-    cached_stats = cache.get('stats_transmitters')
     if not ids or not observers:
         try:
             cache_statistics()
-            cached_stats = cache.get('stats_transmitters')
             ids = cache.get('satellites_ids')
             observers = cache.get('stats_observers')
         except OperationalError:
@@ -339,10 +289,7 @@ def stats(request):
     return render(
         request, 'base/stats.html', {
             'satellites': cached_satellites,
-            'observers': observers,
-            'statistics': cached_stats,
-            'contributor_count': contributor_count,
-            'suggestion_count': suggestion_count,
+            'observers': observers
         }
     )
 
@@ -388,7 +335,7 @@ class TransmitterCreateView(LoginRequiredMixin, BSModalCreateView):
                        reviewed by a moderator. Thanks for contibuting!'
 
     satellite = Satellite()
-    user = User()
+    user = get_user_model()
 
     def dispatch(self, request, *args, **kwargs):
         """
@@ -405,30 +352,8 @@ class TransmitterCreateView(LoginRequiredMixin, BSModalCreateView):
         transmitter = form.instance
         transmitter.satellite = self.satellite
         transmitter.user = self.user
-
-        # Notify admins
-        admins = User.objects.filter(is_superuser=True)
-        site = Site.objects.get_current()
-        subject = '[{0}] A new suggestion for {1} was submitted'.format(
-            site.name, transmitter.satellite.name
-        )
-        template = 'emails/new_transmitter_suggestion.txt'
-        saturl = '{0}{1}'.format(
-            site.domain,
-            reverse('satellite', kwargs={'norad': transmitter.satellite.norad_cat_id})
-        )
-        data = {
-            'satname': transmitter.satellite.name,
-            'saturl': saturl,
-            'sitedomain': site.domain,
-            'contributor': transmitter.user
-        }
-        message = render_to_string(template, {'data': data})
-        for user in admins:
-            try:
-                user.email_user(subject, message, from_email=settings.DEFAULT_FROM_EMAIL)
-            except Exception:  # pylint: disable=W0703
-                LOGGER.error('Could not send email to user', exc_info=True)
+        if not self.request.is_ajax():
+            notify_transmitter_suggestion.delay(transmitter.satellite.id, self.user.id)
         return super().form_valid(form)
 
     def get_success_url(self):
@@ -443,7 +368,7 @@ class TransmitterUpdateView(LoginRequiredMixin, BSModalUpdateView):
     success_message = 'Your transmitter suggestion was stored successfully and will be \
                        reviewed by a moderator. Thanks for contibuting!'
 
-    user = User()
+    user = get_user_model()
 
     def get_initial(self):
         initial = {}
@@ -459,31 +384,8 @@ class TransmitterUpdateView(LoginRequiredMixin, BSModalUpdateView):
         transmitter.user = self.user
         transmitter.reviewed = False
         transmitter.approved = False
-
-        # Notify admins
-        admins = User.objects.filter(is_superuser=True)
-        site = Site.objects.get_current()
-        subject = '[{0}] A new suggestion for {1} was submitted'.format(
-            site.name, transmitter.satellite.name
-        )
-        template = 'emails/new_transmitter_suggestion.txt'
-        saturl = '{0}{1}'.format(
-            site.domain,
-            reverse('satellite', kwargs={'norad': transmitter.satellite.norad_cat_id})
-        )
-        data = {
-            'satname': transmitter.satellite.name,
-            'saturl': saturl,
-            'sitedomain': site.domain,
-            'contributor': transmitter.user
-        }
-        message = render_to_string(template, {'data': data})
-        for user in admins:
-            try:
-                user.email_user(subject, message, from_email=settings.DEFAULT_FROM_EMAIL)
-            except Exception:  # pylint: disable=W0703
-                LOGGER.error('Could not send email to user', exc_info=True)
-
+        if not self.request.is_ajax():
+            notify_transmitter_suggestion.delay(transmitter.satellite.id, self.user.id)
         return super().form_valid(form)
 
     def get_success_url(self):
